@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-push-scroller-extension.c,v 1.4 2006/09/13 19:01:24 chpe Exp $
+ *  $Id: ephy-push-scroller-extension.c 1631 2007-11-04 00:33:41Z cyrilbois $
  */
 
 #include "config.h"
@@ -67,7 +67,7 @@ dom_mouse_down_cb (EphyEmbed *embed,
 
 	button = ephy_embed_event_get_button (event);
 	context = ephy_embed_event_get_context (event);
-	
+
 	if (button != 2 || (context & EPHY_EMBED_CONTEXT_INPUT) ||
             (context & EPHY_EMBED_CONTEXT_LINK))
 	{
@@ -85,21 +85,18 @@ dom_mouse_down_cb (EphyEmbed *embed,
 
 static void
 impl_detach_window (EphyExtension *ext,
-                    EphyWindow *window)
+		    EphyWindow *window)
 {
-        g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
+	g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
 }
 
 static void
 impl_attach_tab (EphyExtension *ext,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
-	EphyEmbed *embed;
-
 	LOG ("impl_attach_tab");
 
-	embed = ephy_tab_get_embed (tab);
 	g_return_if_fail (embed != NULL);
 
 	g_signal_connect_object (embed, "ge-dom-mouse-down",
@@ -109,13 +106,10 @@ impl_attach_tab (EphyExtension *ext,
 static void
 impl_detach_tab (EphyExtension *ext,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
-	EphyEmbed *embed;
-
 	LOG ("impl_detach_tab");
 
-	embed = ephy_tab_get_embed (tab);
 	g_return_if_fail (embed != NULL);
 
 	g_signal_handlers_disconnect_by_func
