@@ -16,13 +16,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-states-extension.c,v 1.8 2006/09/13 19:01:38 chpe Exp $
+ *  $Id: ephy-tab-states-extension.c 1641 2007-11-17 12:47:10Z cyrilbois $
  */
 
 #include "config.h"
 
 #include "ephy-tab-states-extension.h"
 
+#include <epiphany/ephy-embed-container.h>
 #include <epiphany/ephy-extension.h>
 #include "eel-gconf-extensions.h"
 #include "ephy-debug.h"
@@ -141,7 +142,7 @@ ephy_tab_states_extension_finalize (GObject *object)
 
 static GtkWidget *
 get_real_tab_label (EphyWindow *window,
-		    EphyTab *tab)
+		    EphyEmbed *tab)
 {
 	GtkWidget *hbox, *label, *notebook;
 
@@ -169,12 +170,12 @@ sync_active_tab (EphyWindow *window,
 		 GParamSpec *pspec,
 		 EphyTabStatesExtension *extension)
 {
-	EphyTab *active_tab;
+	EphyEmbed *active_tab;
 	GtkWidget *label;
 
-	active_tab = ephy_window_get_active_tab (window);
+	active_tab = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 
-	if (ephy_tab_get_load_status (active_tab) == FALSE)
+	if (ephy_embed_get_load_status (active_tab) == FALSE)
 	{
 		/* mark the tab as read */
 		label = get_real_tab_label (window, active_tab);
@@ -186,7 +187,7 @@ sync_active_tab (EphyWindow *window,
 }
 
 static void
-sync_load_status (EphyTab *tab,
+sync_load_status (EphyEmbed *tab,
 		  GParamSpec *pspec,
 		  EphyTabStatesExtension *extension)
 {
@@ -202,7 +203,7 @@ sync_load_status (EphyTab *tab,
 	window = EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab)));
 	g_return_if_fail (window != NULL);
 
-	loading = ephy_tab_get_load_status (tab);
+	loading = ephy_embed_get_load_status (tab);
 
 	if (loading)
 	{
@@ -211,7 +212,7 @@ sync_load_status (EphyTab *tab,
 #endif
 		font_desc = priv->bold_font_desc;
 	}
-	else if (tab != ephy_window_get_active_tab (window))
+	else if (tab != ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window)))
 	{
 #ifdef ENABLE_COLOURS
 		colour = &priv->tab_unread_colour;
@@ -234,7 +235,7 @@ impl_attach_window (EphyExtension *ext,
 
 	LOG ("attach_window window %p", window);
 
-	g_signal_connect (window, "notify::active-tab",
+	g_signal_connect (window, "notify::active-child",
 			  G_CALLBACK (sync_active_tab), extension);
 }
 
@@ -254,7 +255,7 @@ impl_detach_window (EphyExtension *ext,
 static void
 impl_attach_tab (EphyExtension *ext,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *tab)
 {
 	EphyTabStatesExtension *extension = EPHY_TAB_STATES_EXTENSION (ext);
 
@@ -268,7 +269,7 @@ impl_attach_tab (EphyExtension *ext,
 static void
 impl_detach_tab (EphyExtension *ext,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *tab)
 {
 	EphyTabStatesExtension *extension = EPHY_TAB_STATES_EXTENSION (ext);
 
